
clear
set more off

use "$data\Univ_data.dta"
cd "$output"


**********************************************************************************************

gen l_foreign_fresh=l_ENROLL_FRESH_NON_RES_ALIEN_DEG
gen foreign_fresh=ENROLL_FRESH_NON_RES_ALIEN_DEG
label var foreign_fresh "Foreign Freshmen"
label var l_foreign_fresh "Log(Foreign Freshmen)"

local ASC_enroll = "foreign_fresh"

***********************************
*** Balanced Sample:
gen flag=0
foreach data in Delta ASC{
	foreach dep_vars in  test enroll tuition r_tuitionrev tuition_rev expenditure_vars enroll_is{
			gen `data'_`dep_vars'_flag=0
			replace flag=0
			foreach i in ``data'_`dep_vars''{
				replace flag=1 if l_`i'==.
			}
			replace `data'_`dep_vars'_flag=1 if flag==1
	}
}

drop if year>2012
xtset unitid year


gen nom_approp_minus=nominal_approp - 100000*state_ap
gen l_state_app_at_state=log(nom_approp_minus)


**** Pictures
foreach indep_var in  state_app_at_state  { 
	foreach data in Delta ASC{

		foreach dep_vars in  enroll{
			local k=0

			foreach j in Research nonResearch AAU{
	
				preserve
				keep if `j'==1
				drop if `data'_`dep_vars'_flag==1
				sort UnitID year
				xtset unitid year
				foreach i in ``data'_`dep_vars''{
				
					xtreg l_`i' l_`indep_var'  L.l_`indep_var' F.l_`indep_var'    l_population y1-y17  [w=weight], fe cluster(state_of_college)
					
					local `j'_2=_b[l_`indep_var']
					local `j'_2_se=_se[l_`indep_var']
					
					local `j'_3=_b[L.l_`indep_var']
					local `j'_3_se=_se[L.l_`indep_var']	
	
					local `j'_1=_b[F.l_`indep_var']
					local `j'_1_se=_se[F.l_`indep_var']	
	
				}

				restore
			}
		}
	}
}

clear


set obs 9
gen id=_n
gen type="Research" if id<4
replace type="nonResearch" if id>3 & id<7
replace type="AAU" if id>6
gen id2=id
replace id2=id-3 if id>3
replace id2=id-6 if id>6

gen coeff=.
gen se=.


forvalues i=1/3{
	foreach j in Research nonResearch AAU{		
		replace coeff=``j'_`i'' if type=="`j'" & id2==`i'	
		replace se=``j'_`i'_se' if type=="`j'" & id2==`i'
		
		
	}
}

gen ciu=coeff+1.96*se
gen cil=coeff-1.96*se

gen ciu90=coeff+1.64*se
gen cil90=coeff-1.64*se

replace id2=id2-2
label var id2 "Year"

twoway (connected coeff id2 if type=="Research", msymbol(triangle_hollow) ) (rbar ciu90 cil90 id2 if type=="Research", sort fcolor(%40) lwidth(thin) barwidth(0.2)) (rcap ciu cil id2 if type=="Research"),ytitle("Effect of Log Appropriations on Log Foreign") legend(off) title("Research Universities") xtitle("Year (Normalized)") yline(0) scheme(s1color)  xlabel(#3)
graph export Leave_one_out_IV_cluster_Research.png, replace

twoway (connected coeff id2 if type=="nonResearch", msymbol(triangle_hollow) ) (rbar ciu90 cil90 id2 if type=="nonResearch", sort fcolor(%40) lwidth(thin) barwidth(0.2)) (rcap ciu cil id2 if type=="nonResearch"),ytitle("Effect of Log Appropriations on Log Foreign") legend(off) title("Non-Research Universities") xtitle("Year (Normalized)") yline(0) scheme(s1color)  xlabel(#3)
graph export Leave_one_out_IV_cluster_nonResearch.png, replace

twoway (connected coeff id2 if type=="AAU", msymbol(triangle_hollow) ) (rbar ciu90 cil90 id2 if type=="AAU", sort fcolor(%40) lwidth(thin) barwidth(0.2)) (rcap ciu cil id2 if type=="AAU"),ytitle("Effect of Log Appropriations on Log Foreign") legend(off) title("Public AAUs") xtitle("Year (Normalized)") yline(0) scheme(s1color)  xlabel(#3)
graph export Leave_one_out_IV_cluster_AAU.png, replace

