
clear
set more off


use "$data\Univ_data.dta"
cd "$output"

********************************************

sort unitid year
xtset unitid year

** Deflate by HEPI
cap drop r_state_ap r_tuitionrev r_CHRG_FRESH_PUBLIC_TUITION r_CHRG_FRESH_TUITION_OUT_STATE
foreach var in state_ap tuitionrev CHRG_FRESH_PUBLIC_TUITION CHRG_FRESH_TUITION_OUT_STATE{
*gen r_`var'=`var'/cpi
gen r_`var'=`var'/hepi_index*100
label var r_`var' "Real `: variable label `var''"
}

label var r_CHRG_FRESH_TUITION_OUT_STATE "Real Out-State Tuition"
label var r_CHRG_FRESH_PUBLIC_TUITION "Real In-state Tuition"

replace r_state_ap=r_state_ap*100
label var r_state_ap "Real State Appropriations ($1000s)"

gen foreign_freshmen=ENROLL_FRESH_NON_RES_ALIEN_DEG

cap drop d_r_tuitionrev d_r_state_ap
foreach var in r_state_ap  r_CHRG_FRESH_TUITION_OUT_STATE r_CHRG_FRESH_PUBLIC_TUITION  r_tuitionrev foreign_freshmen{ /*r_f1c191 r_f1c192 AMERICAN_OOS IN_STATE_FRESHMEN r_f1c191_pc r_f1c192_pc ENROLL_UG_NON_RES_ALIEN_DEG  OOS_UGRAD IN_STATE_UGRAD*/
gen d_`var'=`var'-L5.`var' if year==2012
label var d_`var' "Change in `: variable label `var''"
format d_`var' %9.0fc
}

keep if Research==1

****************************************************************************************
************** Scatter Plots

set scheme s1color

***************** Make Pictures
gen school_label=""
replace school_label="MSU" if unitid==171100
replace school_label="UMich" if unitid==170976
replace school_label="Berkeley" if unitid==110635
replace school_label="UCLA" if unitid==110662
replace school_label="UVA" if unitid==234076
replace school_label="Indiana" if unitid==151351
*replace school_label="PSU" if unitid==214777
replace school_label="UIUC" if unitid==145637

label var d_foreign_freshmen "Change in Number of Foreign Freshmen"

replace d_r_tuitionrev = d_r_tuitionrev/1000
label var d_r_tuitionrev "Change in Tuition Revenues ($1000s)"

format d_r_state_ap %12.0fc

foreach var in  d_foreign_freshmen d_r_tuitionrev d_r_CHRG_FRESH_TUITION_OUT_STATE d_r_CHRG_FRESH_PUBLIC_TUITION  {  
pwcorr `var' d_r_state_ap, sig
local rho: di %5.4g r(rho)
local t=abs(r(rho))*(sqrt(r(N)-2)/sqrt(1-r(rho)^2))
if `t'>2.57{
	local star="***"
}
else if `t'>1.96{
	local star="**"
}
else if `t'>1.645{
	local star="*"
}
else{
	local star=""
}

twoway  (scatter `var' d_r_state_ap if AAU==0) (scatter `var' d_r_state_ap if AAU==1, mlabel(school_label) msymbol(square_hollow) mcolor(cranberry) mlabcolor(cranberry) ) (lfit `var' d_r_state_ap) , ytitle(`: variable label `var'') legend(order(1 "Other Research" 2 "AAU")) scheme(s1color)  subtitle("corr = `rho'",  position(1) ring(0) margin(large))
graph save state_ap_`var'_April2018, replace
}




foreach var in  d_r_tuitionrev { 
pwcorr `var' d_foreign_freshmen, sig
local rho: di %5.4g r(rho)
local t=abs(r(rho))*(sqrt(r(N)-2)/sqrt(1-r(rho)^2))
if `t'>2.57{
	local star="***"
}
else if `t'>1.96{
	local star="**"
}
else if `t'>1.645{
	local star="*"
}
else{
	local star=""
}

twoway  (scatter `var' d_foreign_freshmen if AAU==0)  (scatter `var' d_foreign_freshmen if AAU==1, mlabel(school_label) msymbol(square_hollow) mcolor(cranberry) mlabcolor(cranberry)) (lfit `var' d_foreign_freshmen) , ytitle(`: variable label `var'') legend(order(1 "Other Research" 2 "AAU")) scheme(s1color) subtitle("corr = `rho'",  position(1) ring(0) margin(large))
graph save foreign_fresh_`var'_April2018, replace
}


graph combine  state_ap_d_r_tuitionrev_April2018.gph foreign_fresh_d_r_tuitionrev_April2018.gph state_ap_d_r_CHRG_FRESH_PUBLIC_TUITION_April2018.gph state_ap_d_r_CHRG_FRESH_TUITION_OUT_STATE_April2018.gph, iscale(*.7) title(Tuition Revenues and Rates (2007-12), size(medsmall))
graph export combined_tuition_April2018.png, replace width(1600)
