
clear
set more off

use "$data\\Univ_data.dta"
cd "$output"


***************************************************************************************************************************
sort unitid year
xtset unitid year

******* USE THE IPEDS INSTEAD OF THE ASC because IPEDS has "fees" as well ***************
replace CHRG_FRESH_TUITION_OUT_STATE=tuition_fee_oos
replace CHRG_FRESH_PUBLIC_TUITION=tuition_fee_instate

** Deflate by HEPI Index instead of CPI
cap drop r_state_ap r_tuitionrev r_CHRG_FRESH_PUBLIC_TUITION r_CHRG_FRESH_TUITION_OUT_STATE
foreach var in tuition_revenue  state_ap tuitionrev CHRG_FRESH_PUBLIC_TUITION CHRG_FRESH_TUITION_OUT_STATE f1c191 f1c192{
gen r_`var'=`var'/hepi_index*100
label var r_`var' "Real `: variable label `var''"
}


**** Total State Appropriations
gen real_app_for_state=nominal_approp/hepi*100
label var real_app_for_state "Appropriations at State Level"

label var r_CHRG_FRESH_TUITION_OUT_STATE "Real Out-State Tuition"
label var r_CHRG_FRESH_PUBLIC_TUITION "Real In-state Tuition"

replace r_state_ap=r_state_ap*100*1000
label var r_state_ap "Real State Appropriations "

label var r_tuitionrev "Real Tuition Revenue"
gen r_tuition_rev_new=r_tuition_revenue
label var r_tuition_rev_new "Real Tuition Revenue"

********************** Accounting Exercise ******************************
** Per student
foreach var in f1c191 f1c192 state_ap tuitionrev CHRG_FRESH_PUBLIC_TUITION{
gen r_`var'_pc=r_`var'/ENROLL_UG_TOTAL_DEG
label var r_`var'_pc "Real per student `: variable label `var''"
}

***** Look at changes between 2007 and 2012
gen r_state_ap_per_student=r_state_ap/ENROLL_UG_TOTAL_DEG 
gen d_r_state_ap_per_student=r_state_ap_per_student - l5.r_state_ap_per_student if year==2012


*** Tutions 5 years ahead
foreach var in r_CHRG_FRESH_TUITION_OUT_STATE r_CHRG_FRESH_PUBLIC_TUITION{
gen f`var'=f5.`var' if year==2007
label var f`var' "Forward 5 `: variable label `var''"
}

cap drop d_r_tuitionrev d_r_state_ap
foreach var in r_state_ap r_tuition_rev_new AMERICAN_OOS IN_STATE_FRESHMEN r_f1c191_pc r_f1c192_pc ENROLL_UG_NON_RES_ALIEN_DEG  OOS_UGRAD IN_STATE_UGRAD r_CHRG_FRESH_TUITION_OUT_STATE r_CHRG_FRESH_PUBLIC_TUITION r_f1c191 r_f1c192 r_tuitionrev {
gen d_`var'=`var'-L5.`var' if year==2012
label var d_`var' "Change in `: variable label `var''"
format d_`var' %9.0fc
}


***** Fractions
gen fraction_foreign=ENROLL_UG_NON_RES_ALIEN_DEG/ENROLL_UG_TOTAL_DEG
gen fraction_oos=UG_OUT_OF_STATE_PCT/100
gen fraction_instate=IN_STATE_UGRAD/ENROLL_UG_TOTAL_DEG

** Tuition differential between in-state and out-state
gen r_tuition_diff=r_CHRG_FRESH_TUITION_OUT_STATE-r_CHRG_FRESH_PUBLIC_TUITION

xtset unitid year

foreach var in r_tuitionrev_pc fraction_foreign fraction_oos fraction_instate r_tuition_diff{
  gen d_`var' = `var' - l5.`var' if year==2012  
  gen u_`var'=`var' if year>2006 & year<.
  format d_`var' %9.0fc
  ** Get averages
  egen avg_`var'=mean(`var'), by(unitid)
}


*** Accounting Output
gen d_foreign_tuition_diff =avg_r_tuition_diff*d_fraction_foreign
gen d_oos_tuition_diff =avg_r_tuition_diff*d_fraction_oos
gen foreign_d_tuition_diff=avg_fraction_foreign*d_r_tuition_diff
gen oos_d_tuition_diff=avg_fraction_oos*d_r_tuition_diff
gen total_change=d_r_CHRG_FRESH_PUBLIC_TUITION + d_foreign_tuition_diff + d_oos_tuition_diff + foreign_d_tuition_diff + oos_d_tuition_diff

foreach var in d_foreign_tuition_diff d_oos_tuition_diff foreign_d_tuition_diff oos_d_tuition_diff d_r_CHRG_FRESH_PUBLIC_TUITION total_change{
gen s_`var' = `var'/total_change
}


drop if s_d_foreign_tuition_diff==. & year==2012

replace Research=0 if Research==.

*** Short Table for top 2 by Baseline Enrollment
cap drop ranku*
bysort state_of_college Research: egen ranku2 = rank(-state_ap) if year==1996, unique
egen ranku=mean(ranku2), by(unitid)


label var state_of_college "State"
*keep if inlist(state_of_college,"Michigan", "California","Illinois","Indiana", "Ohio")
keep if inlist(state_of_college,"Michigan", "California","New York","Indiana", "Wisconsin") 

sort state_of_college Research instnm

gen sample_Table6=0
replace sample_Table6=1 if inlist(unitid ,110422,	110565,	110635,	110662,	151360,	151102,	151351,	243780,	169248,	171456,	171100,	170976,	214041,	216764,	214777,	215293,	240329,	240365,	240444,	240453) 
replace sample_Table6=1 if inlist(unitid , 196130, 196149, 196060, 196088)



**table 5

export excel state_of_college instnm Research s_d_foreign_tuition_diff s_d_oos_tuition_diff s_foreign_d_tuition_diff s_oos_d_tuition_diff s_d_r_CHRG_FRESH_PUBLIC_TUITION total_change d_r_state_ap_per_student  using Table6.xls if year==2012 & sample_Table6==1, first(varl) replace

