
clear
set more off

use "$data\Univ_data.dta"
cd "$output"


***************************************************************************************************************************

*** Define Locals for Dependent Variables

local Delta_expenditure_vars="eandg01"
local ASC_tuition="tuition_fee_instate tuition_fee_oos " 


************************************************************************
*** Bbalanced Sample - within a year, the same number of universities 
gen flag=0
foreach data in Delta ASC{
	foreach dep_vars in  tuition expenditure_vars{
			gen `data'_`dep_vars'_flag=0
			replace flag=0
			foreach i in ``data'_`dep_vars''{
				replace flag=1 if l_`i'==.
			}
			replace `data'_`dep_vars'_flag=1 if flag==1
	}
}


gen nom_approp_minus=nominal_approp - 100000*state_ap
gen l_state_app_at_state=log(nom_approp_minus)
local ivs="l_state_app_at_state"

local ASC_tuition="tuition_fee_instate"

gen log_FTE=log(ENROLL_UG_TOTAL_DEG)

*** Early v Late
keep if Research==1
gen early=(year<2005)
gen late=(year>2004)

*** OLS with Log FTE
foreach indep_var in state_ap { 
	foreach data in Delta ASC{
		foreach dep_vars in  tuition expenditure_vars{
			local k=0
			foreach j in early late{

				preserve
				keep if `j'==1
				drop if `data'_`dep_vars'_flag==1
				sort UnitID year
				foreach i in ``data'_`dep_vars''{
					
					xtreg l_`i' l_`indep_var' l_population y1-y17 log_FTE [w=weight], fe cluster(unitid)
					summ l_`i' if e(sample)==1
					local mean_dep=r(mean)
					local mean_dep=round(`mean_dep', 0.01)
					if `k'==0{
						outreg2 `indep_var' l_population  using reg_`dep_vars'_`indep_var'_`data'.xls, keep(l_`indep_var' l_population log_FTE) replace cttop("`: variable label `i''") addtext(Mean Dependent Variable, `mean_dep', Sample, `j', Data, `data', Style, "Logs", Weights, "Undergrad Population", Fixed Effects, "University and Year") se asterisk(se) label bdec(3) sdec(3)
					}
					else{
						outreg2 `indep_var' l_population  using reg_`dep_vars'_`indep_var'_`data'.xls, keep(l_`indep_var' l_population log_FTE)  append cttop("`: variable label `i''") addtext(Mean Dependent Variable, `mean_dep', Sample, `j', Data, `data', Style, "Logs", Weights, "Undergrad Population", Fixed Effects, "University and Year") se asterisk(se) label bdec(3) sdec(3)
					}
					local k=1
					
								
					
				}

				restore
			}
		}
	}
}
